@@ -2,8 +2,15 @@
 
 from __future__ import with_statement
 
-import contextlib, multiprocessing, os, subprocess, sys, tempfile, \
-time, warnings
+import contextlib
+import logging
+import multiprocessing
+import os
+import subprocess
+import sys
+import tempfile
+import time
+import warnings
 
 from UserDict import UserDict
 from copy import copy
@@ -11,6 +18,8 @@ from datetime import datetime, timedelta
 
 from decorator import decorator
 
+log = logging.getLogger('clepy')
+
 def listmofize(x):
 
     """
@@ -196,9 +205,9 @@ def send_through_pager(s, pager=None):
 
 def draw_ascii_spinner(delay=0.2):
     for char in '/-\\|':
+        time.sleep(delay)
         sys.stderr.write(char)
         sys.stderr.flush()
-        time.sleep(delay)
         sys.stderr.write('\r')
 
 
@@ -237,6 +246,14 @@ def maybe_add_ellipses(s, maxlen=72):
     else:
         return "%s..." % s[:maxlen]
 
+def figure_out_editor():
+    """
+    Return a list like ['/usr/bin/vim'] or ['mate', '-w']
+    based on os.environ['EDITOR'], defaulting to 'vi'.
+    """
+
+    return os.environ.get('EDITOR', 'vi').split(' ')
+
 
 def edit_with_editor(s=None):
     """
@@ -245,15 +262,17 @@ def edit_with_editor(s=None):
     Returns the text typed in the editor, after running strip().
     """
 
-    # This is the first time I've used with!
-    with tempfile.NamedTemporaryFile() as t:
+    t = tempfile.NamedTemporaryFile()
 
-        if s:
-            t.write(str(s))
-            t.seek(0)
+    if s:
+        t.write(str(s))
+        t.flush()
+        t.seek(0)
 
-        subprocess.call([os.environ.get('EDITOR', 'vi'), t.name])
-        return t.read().strip()
+    subprocess.call(figure_out_editor() + [t.name])
+    t.seek(0)
+
+    return t.read().strip()
 
 
 def csum(seq):
